{{
this is a dummy object that does nothing.
it simply gives us the routines to call dynamically loaded objects
}}
  'Names for methods in your objects
  'I suggest that you allow $100 between each object. This allows 256 methods per object.
  'You should prefix the names with some identifier so that you don't run out of constant names.
  'There are constants defined at the end of this file for Text drivers. At some stage I will add
  'constants for other drivers as well. (Planning on comboKeyboard, some serial, twi, graphics
  'and maybe some others. If you do one of these I will include it in DOL to save people typing.)
  'You should also provide some basic documentation like what is shown for the DOL objects so that
  'if you release your object it will be easy for others to use.
  'object 1
  #$2000

  'object 2
  #$2100
  

  'Names for object methods
  'All of these MUST be implemented even if they do nothing.
  #0
  init          'Called while loading an object to determine where to modify the object
  run           'DOL equivalent of start
  stop          'Called when an object is being unloaded. It should free any memory,
                'release any locks and stop any cogs started.
  getType       'This will be called while loading an object to determine if this type of object is
                'already loaded. If it is, then we only need to allocate room for the VAR section.
                                'It should return a unique long. Not implemented yet. May not be able to do this.


  'Names for DOL methods
  #0
  DOLload       'Load another object
                'arg1: None (use 0), may be used later for loading multiple copies of an object
                'arg2: pointer to the filename (string)
                'returns: objectName use to call the object
                'aborts: AbortNotEnoughMemory, AbortTooManyObjects, AbortCouldNotFindMethod
                '        AbortCouldNotFindFile
                 
  DOLunload     'Unload an object
                'arg1: objectName
                'arg2: none (use 0)
                'returns: nothing
                'aborts: AbortCouldNotFindObject
                
  DOLgetStart   'Get the start address of an object
                'arg1: objectName
                'arg2: none (use 0)
                'returns: the start address of an object
                'aborts: AbortCouldNotFindObject
                
  DOLgetLength  'Get the length of an object (Program + VAR)
                'arg1: objectName
                'arg2: none (use 0)
                'returns: length of Program + VAR of object
                'aborts: AbortCouldNotFindObject
                
  DOLallocate   'Dynamically allocate some memory from the heap at runtime
                'arg1: the number of longs to allocate
                'arg2: none (use 0)
                'returns: the start address of the memory allocated
                'aborts: AbortNotEnoughMemory
                
  DOLfree       'Frees memory that has been allocated with DOLallocate
                'arg1: start address of memory to deallocate
                'arg2: none(use 0)
                'returns: nothing
                'aborts: not sure
                
  DOLsaveToSD   'Saves an object to an SD card including its VAR section-not implemented
                'arg1: objectName
                'arg2: pointer to file name
                'returns: not sure
                'aborts: not sure
                
  DOLrestoreFromSD
                'Restores an object from an SD card including its VAR section-not implemented
                'arg1: pointer to file name
                'arg2: not sure
                'returns: objectName
                'aborts: not sure

  DOLopenFile   'Opens a file on the SD card with fsrw. See fsrwFemto for more info
                'arg1: pointer to file name
                'arg2: mode ("r"-read, "w"-write, "a"-append, or "d"-delete)
                'returns: see fsrwFemto 
                'aborts: see fsrwFemto

  DOLread       'Reads some data from the open file on the SD card
                'arg1: pointer to where to start writing data
                'arg2: number of bytes to read
                'returns: number of bytes read or a negative error value
                'aborts: not sure
                                
  DOLgetc       'Read a single byte from the SD card
                'arg1: none (use 0)
                'arg2: none (use 0)
                'returns: byte read, -1 if end of file or negative value if an error occurs
                'aborts: not sure
                                
  DOLwrite      'Write some data to the SD card
                'arg1: pointer to where to start reading from
                'arg2: number of bytes to write
                'returns: number of bytes written or a negative value if an error occurs
                'aborts: not sure
                                
  DOLputc       'Writes a single byte to the SD card
                'arg1: byte to add to file
                'arg2: none (use 0)
                'returns: 0 if successful or a negative value if an error occurs
                'aborts: not sure
                                
  DOLcloseFile  'Closes the currently open file
                'arg1: none (use 0)
                'arg2: none (use 0)
                'returns: 0 if successful otherwise not sure
                'aborts: not sure

  DOLavailable  'Gets the largest memory block available
                'arg1: none (use 0)
                'arg2: none (use 0)
                'returns: number of bytes
                'aborts: none

  'object number for DOL
  DOL=0

  'abort values
  #0
  AbortNotEnoughMemory      'There is not enough memory left to complete the operation
  AbortCouldNotFindObject   'The object that we are looking for is not loaded
  AbortCouldNotFindMethod   'The method that we are looking for could not be found
  AbortTooManyObjects       'The maximum number of objects has been reached (currently 16)
  AbortObjectHasThatName    'There is already an object that has that name
  AbortCouldNotFindFile     'The file could not be found

  'methods for text objects such as VGA_Text or TV_Text
  #$100
  TextStr                   'print a string
                            'arg1: pointer to start of zero terminated string
                            'arg2: none (use 0)
                            'returns: nothing
                            'aborts: none
                            
  TextDec                   'print a decimal value
                            'arg1: value
                            'arg2: none (use 0)
                            'returns: nothing
                            'aborts: none
                            
  TextHex                   'print a hexadecimal value
                            'arg1: value
                            'arg2: number of digits to print
                            'returns: nothing
                            'aborts: none
                            
  TextBin                   'print a string binary value
                            'arg1: value
                            'arg2: number of digits to print
                            'returns: nothing
                            'aborts: none
                            
  TextOut                   'outputs a character or performs control function
                            'arg1: character or command
                            'arg2: none (use 0)
                            'returns: nothing
                            'aborts: none
                            
  TextSetColors             'sets colors, see object documentation
                            'arg1: colorptr
                            'arg2: none (use 0)
                            'returns: nothing
                            'aborts: none
                                                        
  'methods for keyboard objects such as DYNkbm
  #$200
  KPresent                  'Check if keyboard is present
                            'arg1: none (use 0)
                            'arg2: none (use 0)
                            'returns: true / false
                            'aborts: none

  Kkey                      'gets a key (never waits)
                            'arg1: none (use 0)
                            'arg2: none (use 0)
                            'returns: key pressed or 0 if the buffer is empty
                            'aborts: none
  
  KgetKey                   'get next key (may wait for keypress)
                            'arg1: none (use 0)
                            'arg2: none (use 0)
                            'returns: key pressed
                            'aborts: none

  KnewKey                   'clear buffer and get new key (always waits for keypress)
                            'arg1: none (use 0)
                            'arg2: none (use 0)
                            'returns: key pressed
                            'aborts: none

  KgotKey                   'check if any key is in the buffer
                            'arg1: none (use 0)
                            'arg2: none (use 0)
                            'returns: true / false
                            'aborts: none

  KclearKeys                'clears the key buffer
                            'arg1: none (use 0)
                            'arg2: none (use 0)
                            'returns: nothing
                            'aborts: none

  KkeyState                 'gets the start of a particular key
                            'arg1: key to check
                            'arg2: none (use 0)
                            'returns: true / false
                            'aborts: none

  Kkeyblocks                'sets up the different locks- see object docs

  'methods for mouse objects such as DYNkbm
  #$300
  Mpresent                  'Check if mouse is present
                            'arg1: none (use 0)
                            'arg2: none (use 0)
                            'returns: type of mouse connected - see object docs
                            'aborts: none

  Mbutton                   'Gets the state of a particular button
                            'arg1: button to check - see object docs
                            'arg2: none (use 0)
                            'returns: true / false
                            'aborts: none
                            
  Mbuttons                  'Gets the state of all buttons
                            'arg1: none (use 0)
                            'arg2: none (use 0)
                            'returns: buttons - see object docs
                            'aborts: none
                            

  Mbound_limits             'Set bounding limits
                            'arg1: pointer to long xmin, ymin, zmin, xmax, ymax, zmax
                            'arg2: none (use 0)
                            'returns: none
                            'aborts: none

  Mbound_scales             'Set bounding scales
                            'arg1: pointer to long x_scale, y_scale, z_scale
                            'arg2: none (use 0)
                            'returns: none
                            'aborts: none

  Mbound_x                  'Get bound x
                            'arg1: none (use 0)
                            'arg2: none (use 0)
                            'returns: bound value
                            'aborts: none

  Mbound_y                  'Get bound y
                            'arg1: none (use 0)
                            'arg2: none (use 0)
                            'returns: bound value
                            'aborts: none

  Mbound_z                  'Get bound z
                            'arg1: none (use 0)
                            'arg2: none (use 0)
                            'returns: bound value
                            'aborts: none
                           
PUB main
PUB callObj(objectName,methodName,arg1,arg2)
return