{{
This object demonstrates the format that all objects that want to be loaded with DOL must follow
To call another object you first need to ensure that the object is loaded. Either by this object or
by another object.

To call another object do
c.callObj(objectName,c#methodName,arg1,arg2)

When you load other objects, you need to store the value returned so that you can run
methods in it.

To call DOL do
c.callObj(c#DOL,c#methodName,arg1,arg2)

DOL uses aborts for a lot of the calls to it so you will need to catch them and check whether aborted is true.

The first file to be loaded MUST be named "kernal.bin" and it must have a "run" method.
If it doesn't, DOL will simply stop the chip.
}}
CON
  _clkmode = xtal1 + pll16x
  _xinfreq = 5_000_000

VAR long aborted 'stores the address of where
    long text 
    long otherObject
    long memStart
        
DAT endOfObjects long 0

OBJ wm : "Graphics_Demo"

PUB methodRunner(methodName,arg1,arg2)|temp
{{
This MUST be the first method in the object. It is called whenever another object wants to call a method
in this object. It is also called during loading to setup the object for use with DOL. All the different cases
MUST have a return or else the abort at the end will be called.
}}
  
  lockclr(0)
  case methodName
    c#init: 'Do NOT change the init section, if you do you will probably break your object and DOL
      word[@endOfObjects-4]:=arg1.word[0]
      word[@endOfObjects-2]:=arg1.word[1]
      aborted:=arg2
      return
          
    c#run:
      'If this is the first object to be loaded by DOL, this method will be called.
      'You should use this like the start method that is normally used in SPIN.
      'Use it to setup anything that needs setting up such as starting drivers.
      wm.start 
      return
          
    c#stop:
      'This is called when the object is unloaded. It should
      'free any memory that this object has allocated, stop any cogs that this object has started
      'and unload any objects that this object has loaded.
      return

    'You can add other things here you should add a constant for them in dummyObject2.spin.
    'This way, it is easier for other objects to call this object.
  long[aborted]:=true
  abort c#AbortCouldNotFindMethod 'aborts if the method that we wanted to run could not be found

OBJ
  c : "dummyObject2"